@@ -4,7 +4,7 @@
 # Requires mktemp and stat from coreutils
 # ***************************************
 
-source "helpers.sh"
+source "test-helpers.sh"
 
 DC3DD="../src/dc3dd"
 
@@ -249,7 +249,8 @@ verify_split_output()
    check_split_output_file "verify_split_output" "$OUTPUT_FILE" "$REF_FILE_BYTES" "$REF_FILE_MD5_HASH" "$REF_FILE_SHA1_HASH"
    check_input_logging "verify_split_output" "$LOG" "$REF_SECTOR_SIZE" "(assumed)" "$REF_FILE_BYTES" "$REF_FILE_SECTORS"
    check_input_hash_logging "verify_split_output" "$LOG" "$REF_FILE_MD5_HASH" "$REF_FILE_SHA1_HASH"
-   MSG_COUNT=`grep -c "output hashing" "$LOG"`
+   # MSG_COUNT=`grep -c "output hashing" "$LOG"` #for versions < 7.2.635
+   MSG_COUNT=`grep -c "hashed" "$LOG"` #for versions => 7.2.635
    if [ "$MSG_COUNT" -ne "1" ]
    then
       echo "verify_output: missing final output hashing progress message"
